==> react-lds-8.7.0.tgz: package/es/components/Tabs/Tabs.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.object.set-prototype-of";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ControlledTabs from './ControlledTabs';

var Tabs =
/*#__PURE__*/
function (_Component) {
  _inherits(Tabs, _Component);

  function Tabs(props) {
    var _this;

    _classCallCheck(this, Tabs);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Tabs).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "getOnTabChange", function () {
      return function (id) {
        var onChangeTab = _this.props.onChangeTab;

        _this.setState({
          activeTab: id
        });

        if (onChangeTab) {
          onChangeTab(id);
        }
      };
    });

    var _this$props = _this.props,
        children = _this$props.children,
        defaultActiveTab = _this$props.defaultActiveTab;
    var firstId = defaultActiveTab || Tabs.getFirstChildId(children);
    _this.state = {
      activeTab: firstId
    };
    return _this;
  }

  _createClass(Tabs, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(_ref) {
      var nextChildren = _ref.children;
      var children = this.props.children;

      if (nextChildren.length !== children.length) {
        this.setState({
          activeTab: Tabs.getFirstChildId(nextChildren)
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          _ = _this$props2.defaultActiveTab,
          rest = _objectWithoutProperties(_this$props2, ["defaultActiveTab"]);

      var activeTab = this.state.activeTab;
      return React.createElement(ControlledTabs, _extends({}, rest, {
        onChangeTab: this.getOnTabChange(),
        activeTab: activeTab
      }));
    }
  }]);

  return Tabs;
}(Component);

_defineProperty(Tabs, "defaultProps", {
  defaultActiveTab: null,
  onChangeTab: null,
  renderInactiveTabs: false,
  scoped: false,
  size: null,
  styled: false
});

_defineProperty(Tabs, "getFirstChildId", function (children) {
  var childArray = React.Children.toArray(children);
  var firstChild = childArray[0];
  if (!firstChild) return null;
  var id = firstChild.props.id;
  return id;
});

Tabs.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * One or more Tab components
   */
  children: PropTypes.node.isRequired,

  /**
   * Id of the Tab that should be rendered first. Uses first tab of not passed
   *
   */
  defaultActiveTab: PropTypes.string,

  /**
   * Callback triggered when the Tab is changed. Receives (nextIndex)
   */
  onChangeTab: PropTypes.func,

  /**
   * When this is true, inActive tabs will be rendered and hidden with .slds-hide instead of returning null
   */
  renderInactiveTabs: PropTypes.bool,

  /**
   * Renders scoped variant
   */
  scoped: PropTypes.bool,

  /**
   * Size modifier
   */
  size: PropTypes.oneOf(['medium', 'large']),

  /**
   * Renders Card-like variant
   */
  styled: PropTypes.bool
} : {};
export default Tabs;

==> react-lds-9.1.0.tgz: package/es/components/Tabs/Tabs.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ControlledTabs from './ControlledTabs';

var Tabs =
/*#__PURE__*/
function (_Component) {
  _inherits(Tabs, _Component);

  function Tabs(props) {
    var _this;

    _classCallCheck(this, Tabs);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Tabs).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "getOnTabChange", function () {
      return function (id) {
        var onChangeTab = _this.props.onChangeTab;

        _this.setState({
          activeTab: id
        });

        if (onChangeTab) {
          onChangeTab(id);
        }
      };
    });

    var _this$props = _this.props,
        children = _this$props.children,
        defaultActiveTab = _this$props.defaultActiveTab;
    var firstId = defaultActiveTab || Tabs.getFirstChildId(children);
    _this.state = {
      activeTab: firstId
    };
    return _this;
  }

  _createClass(Tabs, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(_ref) {
      var nextChildren = _ref.children;
      var children = this.props.children;

      if (nextChildren.length !== children.length) {
        this.setState({
          activeTab: Tabs.getFirstChildId(nextChildren)
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          _ = _this$props2.defaultActiveTab,
          rest = _objectWithoutProperties(_this$props2, ["defaultActiveTab"]);

      var activeTab = this.state.activeTab;
      return React.createElement(ControlledTabs, _extends({}, rest, {
        onChangeTab: this.getOnTabChange(),
        activeTab: activeTab
      }));
    }
  }]);

  return Tabs;
}(Component);

_defineProperty(Tabs, "defaultProps", {
  defaultActiveTab: null,
  onChangeTab: null,
  renderInactiveTabs: false,
  scoped: false,
  size: null,
  styled: false
});

_defineProperty(Tabs, "getFirstChildId", function (children) {
  var childArray = React.Children.toArray(children);
  var firstChild = childArray[0];
  if (!firstChild) return null;
  var id = firstChild.props.id;
  return id;
});

Tabs.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * One or more Tab components
   */
  children: PropTypes.node.isRequired,

  /**
   * Id of the Tab that should be rendered first. Uses first tab of not passed
   *
   */
  defaultActiveTab: PropTypes.string,

  /**
   * Callback triggered when the Tab is changed. Receives (nextIndex)
   */
  onChangeTab: PropTypes.func,

  /**
   * When this is true, inActive tabs will be rendered and hidden with .slds-hide instead of returning null
   */
  renderInactiveTabs: PropTypes.bool,

  /**
   * Renders scoped variant
   */
  scoped: PropTypes.bool,

  /**
   * Size modifier
   */
  size: PropTypes.oneOf(['medium', 'large']),

  /**
   * Renders Card-like variant
   */
  styled: PropTypes.bool
} : {};
export default Tabs;
